#
# spec file for package kio
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Full KF5 version (e.g. 5.33.0)
%{!?_kf5_version: %global _kf5_version %{version}}
# Last major and minor KF5 version (e.g. 5.33)
%{!?_kf5_bugfix_version: %define _kf5_bugfix_version %(echo %{_kf5_version} | awk -F. '{print $1"."$2}')}
%define qt5_version 5.15.2
%bcond_without released
Name:           kio
Version:        5.113.0
Release:        1.1
Summary:        Network transparent access to files and data
License:        LGPL-2.1-or-later
URL:            https://www.kde.org
Source:         %{name}-%{version}.tar.xz
%if %{with released}
Source1:        %{name}-%{version}.tar.xz.sig
Source2:        frameworks.keyring
%endif
# PATCH-FIX-OPENSUSE kio_help-fallback-to-kde4-docs.patch -- allow kio_help to see into kde4 documentation, needed especially for khelpcenter5
Patch0:         kio_help-fallback-to-kde4-docs.patch
BuildRequires:  extra-cmake-modules >= %{_kf5_version}
BuildRequires:  fdupes
# gcc7 is too old for std::transform_reduce
%if 0%{?suse_version} == 1500
BuildRequires:  gcc10-c++
BuildRequires:  gcc10-PIE
%endif
BuildRequires:  krb5-devel
BuildRequires:  libacl-devel
BuildRequires:  libattr-devel
BuildRequires:  pkgconfig
BuildRequires:  cmake(KF5Archive) >= %{_kf5_version}
BuildRequires:  cmake(KF5Bookmarks) >= %{_kf5_version}
BuildRequires:  cmake(KF5Completion) >= %{_kf5_version}
BuildRequires:  cmake(KF5Config) >= %{_kf5_version}
BuildRequires:  cmake(KF5ConfigWidgets) >= %{_kf5_version}
BuildRequires:  cmake(KF5CoreAddons) >= %{_kf5_version}
BuildRequires:  cmake(KF5Crash) >= %{_kf5_version}
BuildRequires:  cmake(KF5DBusAddons) >= %{_kf5_version}
BuildRequires:  cmake(KF5DocTools) >= %{_kf5_version}
BuildRequires:  cmake(KF5GuiAddons) >= %{_kf5_version}
BuildRequires:  cmake(KF5I18n) >= %{_kf5_version}
BuildRequires:  cmake(KF5IconThemes) >= %{_kf5_version}
BuildRequires:  cmake(KF5ItemViews) >= %{_kf5_version}
BuildRequires:  cmake(KF5JobWidgets) >= %{_kf5_version}
BuildRequires:  cmake(KF5Notifications) >= %{_kf5_version}
BuildRequires:  cmake(KF5Service) >= %{_kf5_version}
BuildRequires:  cmake(KF5Solid) >= %{_kf5_version}
BuildRequires:  cmake(KF5TextWidgets) >= %{_kf5_version}
BuildRequires:  cmake(KF5Wallet) >= %{_kf5_version}
BuildRequires:  cmake(KF5WidgetsAddons) >= %{_kf5_version}
BuildRequires:  cmake(KF5WindowSystem) >= %{_kf5_version}
BuildRequires:  cmake(KF5XmlGui) >= %{_kf5_version}
BuildRequires:  cmake(Qt5Concurrent) >= %{qt5_version}
BuildRequires:  cmake(Qt5Core) >= %{qt5_version}
BuildRequires:  cmake(Qt5DBus) >= %{qt5_version}
BuildRequires:  cmake(Qt5Network) >= %{qt5_version}
BuildRequires:  cmake(Qt5Qml) >= %{qt5_version}
BuildRequires:  cmake(Qt5Test) >= %{qt5_version}
BuildRequires:  cmake(Qt5UiPlugin) >= %{qt5_version}
BuildRequires:  cmake(Qt5Widgets) >= %{qt5_version}
BuildRequires:  cmake(Qt5X11Extras) >= %{qt5_version}
BuildRequires:  cmake(Qt5Xml) >= %{qt5_version}
BuildRequires:  pkgconfig(mount)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(x11)
Requires:       %{name}-core = %{version}
Requires:       kded >= %{_kf5_version}
# KIO/FileDialog uses klauncher directly, but we can't add Requires, as that would introduce dep cycle
Recommends:     kinit
# Only useful for laptops with hybrid GPU
Recommends:     switcheroo-control

%description
This framework implements almost all the file management functions you
will ever need. In fact, the KDE file manager (Dolphin) and the KDE
file dialog also uses this to provide its network-enabled file management.

%package core
Summary:        Network transparent access to files and data
# core subpackage created with 5.9.0
Conflicts:      kio <= 5.8.0

%description core
This framework implements almost all the file management functions you
will ever need. In fact, the KDE file manager (Dolphin) and the KDE
file dialog also uses this to provide its network-enabled file management.
KIO core libraries, ioslave and daemons.

%package devel
Summary:        Network transparent access to files and data
Requires:       %{name} = %{version}
Requires:       %{name}-core = %{version}
Requires:       cmake(KF5Bookmarks) >= %{_kf5_version}
Requires:       cmake(KF5Completion) >= %{_kf5_version}
Requires:       cmake(KF5Config) >= %{_kf5_version}
Requires:       cmake(KF5CoreAddons) >= %{_kf5_version}
Requires:       cmake(KF5ItemViews) >= %{_kf5_version}
Requires:       cmake(KF5JobWidgets) >= %{_kf5_version}
Requires:       cmake(KF5Service) >= %{_kf5_version}
Requires:       cmake(KF5Solid) >= %{_kf5_version}
Requires:       cmake(KF5WindowSystem) >= %{_kf5_version}
Requires:       cmake(KF5XmlGui) >= %{_kf5_version}
Requires:       cmake(Qt5Concurrent) >= %{qt5_version}
Requires:       cmake(Qt5DBus) >= %{qt5_version}
Requires:       cmake(Qt5Network) >= %{qt5_version}

%description devel
This framework implements almost all the file management functions you
will ever need. In fact, the KDE file manager (Dolphin) and the KDE
file dialog also uses this to provide its network-enabled file management.
Development files.

%lang_package

%prep
%autosetup -p1

%build
%ifarch ppc64
%define _lto_cflags %{nil}
%endif

%if 0%{?suse_version} == 1500
export CXX=g++-10
%endif

%cmake_kf5 -d build

%cmake_build

%install
%kf5_makeinstall -C build
%fdupes %{buildroot}

%find_lang kio --with-man --all-name
%{kf5_find_htmldocs}

%ldconfig_scriptlets core
%ldconfig_scriptlets

%files lang -f kio.lang

%files core
%doc README*
%license LICENSES/*
%dir %{_kf5_plugindir}/kf5
%dir %{_kf5_plugindir}/kf5/kio
%dir %{_kf5_plugindir}/kf5/kiod
%dir %{_kf5_sharedir}/kconf_update
%{_kf5_applicationsdir}/ktelnetservice5.desktop
%{_kf5_applicationsdir}/kcm_trash.desktop
%{_kf5_bindir}/ktelnetservice5
%{_kf5_bindir}/ktrash5
%{_kf5_configdir}/accept-languages.codes
%{_kf5_debugdir}/kio.categories
%{_kf5_debugdir}/*.renamecategories
%{_kf5_libdir}/libKF5KIOCore.so.*
%{_kf5_libdir}/libKF5KIONTLM.so.*
%{_kf5_libexecdir}/kio_http_cache_cleaner
%{_kf5_libexecdir}/kiod5
%{_kf5_plugindir}/kcm_trash.so
%{_kf5_plugindir}/kf5/kio/kio_file.so
%{_kf5_plugindir}/kf5/kio/kio_ftp.so
%{_kf5_plugindir}/kf5/kio/kio_ghelp.so
%{_kf5_plugindir}/kf5/kio/kio_help.so
%{_kf5_plugindir}/kf5/kio/kio_http.so
%{_kf5_plugindir}/kf5/kio/kio_trash.so
%{_kf5_plugindir}/kf5/kio/kio_remote.so
%{_kf5_plugindir}/kf5/kiod/kssld.so
%{_kf5_plugindir}/kf5/kiod/kssld.so
%{_kf5_servicesdir}/http_cache_cleaner.desktop
%{_kf5_servicesdir}/kcmtrash.desktop
%{_kf5_sharedir}/dbus-1/services/org.kde.kiod5.service
%{_kf5_sharedir}/dbus-1/services/org.kde.kioexecd.service
%{_kf5_sharedir}/dbus-1/services/org.kde.kssld5.service
%{_kf5_sharedir}/kconf_update/filepicker.upd

%files
%dir %{_kf5_htmldir}
%dir %{_kf5_htmldir}/en
%dir %{_kf5_plugindir}/kf5/kded
%doc %lang(en) %{_kf5_htmldir}/en/*/
%doc %lang(en) %{_kf5_mandir}/*/kcookiejar5.*
%{_kf5_bindir}/kcookiejar5
%{_kf5_configdir}/kshorturifilterrc
%{_kf5_datadir}/kcookiejar/
%{_kf5_libdir}/libKF5KIOFileWidgets.so.*
%{_kf5_libdir}/libKF5KIOGui.so.*
%{_kf5_libdir}/libKF5KIOWidgets.so.*
%{_kf5_libexecdir}/kioexec
%{_kf5_libexecdir}/kioslave5
%{_kf5_libexecdir}/kpac_dhcp_helper
%{_kf5_notifydir}/proxyscout.notifyrc
%{_kf5_plugindir}/kcm_webshortcuts.so
%{_kf5_plugindir}/kf5/kded/kcookiejar.so
%{_kf5_plugindir}/kf5/kded/proxyscout.so
%{_kf5_plugindir}/kf5/kded/remotenotifier.so
%{_kf5_plugindir}/kf5/kiod/kioexecd.so
%{_kf5_plugindir}/kf5/kiod/kpasswdserver.so
%{_kf5_plugindir}/kf5/urifilters/
%{_kf5_plugindir}/kcm_proxy.so
%dir %{_kf5_plugindir}/plasma/
%dir %{_kf5_plugindir}/plasma/kcms/
%dir %{_kf5_plugindir}/plasma/kcms/systemsettings/
%dir %{_kf5_plugindir}/plasma/kcms/systemsettings_qwidgets/
%{_kf5_plugindir}/plasma/kcms/systemsettings_qwidgets/kcm_netpref.so
%{_kf5_plugindir}/plasma/kcms/systemsettings_qwidgets/kcm_proxy.so
%{_kf5_plugindir}/plasma/kcms/systemsettings_qwidgets/kcm_cookies.so
%{_kf5_plugindir}/plasma/kcms/systemsettings_qwidgets/kcm_webshortcuts.so
%{_kf5_plugindir}/plasma/kcms/systemsettings/kcm_smb.so
%dir %{_kf5_plugindir}/designer
%{_kf5_plugindir}/designer/kio5widgets.so
%{_kf5_servicesdir}/cookies.desktop
%{_kf5_servicesdir}/netpref.desktop
%{_kf5_servicesdir}/proxy.desktop
%{_kf5_servicesdir}/searchproviders/
%{_kf5_servicesdir}/smb.desktop
%{_kf5_servicesdir}/webshortcuts.desktop
%{_kf5_servicetypesdir}/
%{_kf5_sharedir}/dbus-1/services/org.kde.kcookiejar5.service
%{_kf5_sharedir}/dbus-1/services/org.kde.kpasswdserver.service

%files devel
%dir %{_kf5_sharedir}/kdevappwizard
%dir %{_kf5_sharedir}/kdevappwizard/templates
%{_kf5_bindir}/protocoltojson
%{_kf5_dbusinterfacesdir}/kf5_org.kde.KCookieServer.xml
%{_kf5_dbusinterfacesdir}/kf5_org.kde.KDirNotify.xml
%{_kf5_dbusinterfacesdir}/kf5_org.kde.KPasswdServer.xml
%{_kf5_dbusinterfacesdir}/kf5_org.kde.KSlaveLauncher.xml
%{_kf5_dbusinterfacesdir}/kf5_org.kde.kio.FileUndoManager.xml
%{_kf5_sharedir}/kdevappwizard/templates/kioworker.tar.bz2
%{_kf5_includedir}/
%{_kf5_libdir}/cmake/KF5KIO/
%{_kf5_libdir}/libKF5KIOCore.so
%{_kf5_libdir}/libKF5KIOFileWidgets.so
%{_kf5_libdir}/libKF5KIOGui.so
%{_kf5_libdir}/libKF5KIONTLM.so
%{_kf5_libdir}/libKF5KIOWidgets.so
%{_kf5_mkspecsdir}/qt_KIOCore.pri
%{_kf5_mkspecsdir}/qt_KIOFileWidgets.pri
%{_kf5_mkspecsdir}/qt_KIOGui.pri
%{_kf5_mkspecsdir}/qt_KIOWidgets.pri
%{_kf5_mkspecsdir}/qt_KNTLM.pri

%changelog
* Tue Dec  5 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.113.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.113.0
- Changes since 5.112.0:
  * Add KF5 include for KPropertiesDialogPlugin
  * Add build option for KF6 coinstallability
  * Adaptations for shared-mime-info >= 2.3
* Mon Nov  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.112.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.112.0
- Changes since 5.111.0:
  * KDirModel: Refactor _k_slotClear()
  * KDirModel: Replace 'slow' with 'fsType' naming
  * KDirModel: Reduce calls to isSlow()
  * KDirModel: Limit details fetching for network fs
* Mon Oct  9 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.111.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.111.0
- Changes since 5.110.0:
  * dbusactivationrunner: only activate well-formed services (kde#475266)
  * DBusActivationRunner: fix object path according to spec
  * Undeprecate KCoreDirLister::setMimeExcludeFilter
  * Fix incomplete error strings in MimeTypeFinderJob
  * Don't crash if KMountPoint gives nothing back while checking for CIFS (kde#474451)
  * trashimpl: optimize TrashSizeCache::calculateSize
  * trash: Optimize trashimpl::adaptTrashSize
  * [kfilewidget] Fixing saving to files with quotes (kde#426728)
  * KPropertiesDialog: Force PlainText on size label
- Drop patch, merged upstream:
  * 0001-Don-t-crash-if-KMountPoint-gives-nothing-back-while-.patch
* Mon Sep 18 2023 Christophe Marin <christophe@krop.fr>
- Add upstream crash fix (kde#474451)
  * 0001-Don-t-crash-if-KMountPoint-gives-nothing-back-while-.patch
* Wed Sep  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.110.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.110.0
- Changes since 5.109.0:
  * Don't unlink + rename on CIFS mounts during copy operations (kde#454693)
  * KFileWidget: better exclude string that may look like Urls (kde#473228)
  * Fix Ask Jeeves search provider (kde#473297)
* Tue Aug  8 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.109.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.109.0
- Changes since 5.108.0:
  * Use switcheroo-control to find discrete GPUs (kde#449106)
  * file: preserve mode on put (kde#471539)
  * KFileWidget: Use targetUrl to extract urls, better handle absolute urls cases (kde#459485)
  * Add explicit moc includes to sources for moc-covered headers
  * KFileWidget: better exclude string that may look like Urls (kde#473228)
* Mon Jul  3 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.108.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.108.0
- Changes since 5.107.0:
  * Remove qt6 CI builds
  * KUrlRequester: restore unnamed filter compatibility with Plasma file dialog
  * KUrlRequester::setFilter: note syntax change in compiler deprecation warning
  * Add KUrlRequester::nameFilters, deprecate KUrlRequester::filter (kde#369542)
  * KUrlRequester::setFilter: note special filter syntax, allow unnamed filters
  * KCoreDirLister::nameFilter: revert to non-partial matching again
  * filewidgets/kfilewidget: Select and focus filename after canceling overwrite (kde#444515)
  * [previewjob] Check whether thumbRootDevice is valid before access (kde#470845)
- Drop patch, merged upstream:
  * 0001-previewjob-Check-whether-thumbRootDevice-is-valid-be.patch
* Tue Jun 20 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Add patch to fix crash on thumbnail generation (kde#470845):
  * 0001-previewjob-Check-whether-thumbRootDevice-is-valid-be.patch
* Mon Jun  5 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.107.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.107.0
- Changes since 5.106.0:
  * Deprecate KIO::AccessManager and related classes
  * Enable thumbnail caching if thumbnail directory is on an encrypted volume
  * KdirLister: update symlink dir content on file removal (kde#469254)
  * Polish menu before creating platform window
* Sat May  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.106.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.106.0
- Changes since 5.105.0:
  * ApplicationLauncherJob: find mimetype before showing open with dialog
  * KPropertiesDialog: Don't quote the path unnecessarily (kde#467369)
  * KEncodingFileDialog: Sort the list of encodings by name
  * WidgetsAskUserActionHandler: make sure all dialogs are created in the main thread (kde#458709)
  * WidgetsAskUserActionHandler: create message dialog in the main thread (kde#465454)
  * file: make sure to cancel reading if the worker was aborted (kde#358231)
  * autotests: Fix Qt 6.5 compatibility
  * KFileItemActions: don't add service submenus that don't have active actions
  * Improve grammar, wording, add a test check
  * KCoreDirLister: AutoUpdate wasn't incremented when a new lister opened an already listed dir
  * SlaveInterface: Set button icon for "Continue Loading"
  * Set ExitType when running applications as transient systemd services
* Sat Apr  1 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.105.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.105.0
- Changes since 5.104.0:
  * CommandLauncher: call emitResult() as soon as process has started (kde#466359)
  * Also handle copy_file_range failing with ENOENT
  * widgets/renamefiledialog: set number limit again (kde#466636)
* Mon Mar  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.104.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.104.0
- Changes since 5.103.0:
  * DeleteOrTrashJob: when trashing a file in trash:/ delete it instead (kde#459545)
  * Set bug report URL for Windows Shares KCM
  * OpenFileManagerWindowJob: fix opening multiple instances under Wayland [KF5] (kde#463931)
  * Add missing URLs in KCMs for reporting bugs (kde#464600)
  * kshorturifilter: return directly if cmd is empty
  * [kprocessrunner] Use aliased desktop file name for xdg-activation
* Wed Feb  8 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.103.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.103.0
- Changes since 5.102.0:
  * CommandLauncher: Emit error when command was not found
  * Add KUrlNavigator::supportedSchemes, to replace customProtocols
  * Add missing copyFromFile entries to http.json for webdav and webdavs (kde#464450)
  * Mark WorkerBase::needSubUrlData as deprecated
  * [commandlauncherjob] Deprecate setIcon
  * job_error: add missing space between sentences for one string (kde#464631)
  * Correct setDesktopName() docs regarding optionality of .desktop suffix
  * Drop outdated docs for mailto kioslave
  * Add deprecation warnings for KDirOperator::setView(KFile::FileView)
  * Deprecate unused Scheduler::connect/disconnects methods
  * Deprecate Slave::isConnected/setConnected
  * Restore old behavior for KFileFilterCombo::setFilter (kde#463309)
  * KCoreDirListerCache: Remove unnecessary assert
  * KFilePlacesView: Set transientParent on context menu (kde#453532)
  * KURISearchFilterEngine: Use DuckDuckGo as a default shortcut
  * widgets/renamefiledialog: remove bulk rename number limit
* Thu Jan 12 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.102.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.102.0
- Changes since 5.101.0:
  * Restore old behavior for KFileFilterCombo::setFilter
  * [kprocessrunner] Don't specify which desktop the app should be launched on
  * Fix crash when dealing with user notification dialog
  * [WidgetsAskUserActionHandler] Add fallbacks for dialog parent windows (kde#463124)
  * [jobuidelegate] Set window when creating delegate
  * Fix KFileFilterComboTest
  * kdiroperator: fix full file path not being stripped (kde#459900)
  * Fix integer overflow for large files in AccessManager (kde#452972)
  * Pre-select "Delete" in Delete Confirmation Dialog (kde#462845)
  * Make link against KWindowSystem private
  * [KOpenWithDialog] Save search history in state config
  * file_unix: Fix check for hidden NTFS files
  * Use new nomenclature with socket name; use ".socket" suffix
  * Port away from deprecated KService::property overload
  * [previewjob] Deprecate overlayIconSize and overlayIconAlpha
  * Replace KIO::SlaveConfig with KIO::WorkerConfig
  * Remove unused includes
  * [kpropertiesdialog] Remove UI to set DBus startup type
  * when inside a sandbox use different openwith behavior
  * Don't install service desktop files for KCMs in KF6
  * Don't install KonqPopupMenu service type file for KF6
  * Fix typo
  * Port away from deprecated KWindowSystem API
  * webdav docs: remove broken link
* Tue Dec  6 2022 Christophe Marin <christophe@krop.fr>
- Update to 5.101.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.101.0
- Too many changes since 5.100.0, only listing bugfixes:
  * Ignore finished() from the timeoutSpecialCommand (kde#459980)
* Tue Nov  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.100.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.100.0
- Too many changes since 5.99.0, only listing bugfixes:
  * AskUserActionInterface: add DeleteInsteadOfTrash deletion type (kde#431351)
- Drop patch, merged upstream:
  * kio-mr1008-fix-webdav.diff
* Thu Oct 27 2022 Ben Greiner <code@bnavigator.de>
- Add kio-mr1008-fix-webdav.diff
  * Fixes WebDAV upload (kde#460717)
  * https://invent.kde.org/frameworks/kio/-/merge_requests/1008
* Sat Oct  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.99.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.99.0
- Changes since 5.98.0:
  * DesktopExecParser: Fix parsing of TerminalApplication when it contains args (kde#459408)
  * KPropertiesDialog: Split single command entry box into separate exec and args
  * allow hiding permissions tab
  * port http to workerbase
  * Worker template: fix install location
  * kcms/webshortcuts: hide from System Settings' main navigation
  * disable state validation
  * UserNotificationHandler: fix messagebox type mismatches
  * Fix missing details in message dialogs from worker
* Tue Sep  6 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.98.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.98.0
- Changes since 5.97.0:
  * Install WidgetsAskUserActionHandler header
  * file_unix: optimize copy (kde#458001)
  * Add FreeBSD Qt6 CI support
  * KFilePlacesItem: Remove unused enum
  * KFilePlacesModel: Don't show error message on UserCanceled
  * Add overloads for Utils::concatPaths()
  * Use AskUserActionInterface (async) in UserNotificationHandler (kde#451834)
  * Ensure iconForStandardPath() returns user-home for QStandardPaths::HomeLocation (kde#447238)
  * trash:/ set the UDS_LOCAL_PATH (kde#368104)
  * KUrlNavigator: check if typed text matches a relative dir first (kde#353883)
  * FileUndoManager: for copyjob only add undo if it copied something (kde#454226)
  * Use Functors with QMetaObject::invokeMethod()
  * DesktopExecParser: don't kioexec if there is a handler for scheme (kde#442721)
  * force admin worker to run in a thread
  * install workerfactory header
  * introduce RealWorkerFactory
  * revise jobuidelegate factorization
  * [kfileitemactions] Show desktop file actions more prominently (kde#417012)
  * clear state after timeout'd special call
  * make loading UDSEntries from streams thread safe
  * Remove ServiceType from KDED metadata
  * Drop obsolete X11 dependency, introduce WITH_X11 option instead
  * KProcessRunner: fix OpenUrlJob and CommandLauncherJob unittests
  * Don't install service type definition for properties plugins when building without deprecated things
  * Remove service type definition for DnD plugins
  * Sync QT_MIN_VERSION with KF's REQUIRED_QT_VERSION
  * disable state validation
* Sun Aug  7 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.97.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.97.0
- Too many changes since 5.96.0, only listing bugfixes:
  * KRecentDocument: better prevent duplicate bookmark for same href (kde#456046)
  * FileUndoManager: fix job description when undoing a batch-renaming (kde#437510)
  * Fix crash in DropJob (kde#454747)
  * Fix thumbnailer result for parent mime types being overwritten (kde#453480)
  * KImageFilePreview: if no current preview, don't show last one on resize (kde#434912)
* Sun Jul  3 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.96.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.96.0
- Changes since 5.95.0:
  * Remove calls to no-op KNewFileMenu::setViewShowsHiddenFiles
  * rename ioslave_defaults to ioworker_defaults
  * Don't treat KJob::UserDefinedError as unknown error
  * move global enum to worker nomenclature
  * [webrunner] Add debian as new keyword for webrunner
  * [knewfilemenu] Don't forcibly change file extension (kde#456091)
  * [knewfilemenu] Write Name when creating Link files
  * Pass JobUiDelegate's window to created dialogs
  * [knewfilemenu] Always add .desktop suffix when creating link file
  * Deprecated global file class code in KFileWidget
  * KRecentDirs: Deprecate reading/writing to global file
  * [kfileplacesmodel] Cache device display name
  * PreviewJob: Add note about plugins being cached internally
  * KRecentDocuments: Improve indentation in recentlyused.xbel (kde#456046)
  * Add template for empty file (kde#297003)
  * We need it when we build with strict compile
  * Don't duplicate headers between cpp/.h files
  * Don't leak the slave's worker thread
  * filewidgets: update location text after selected files are renamed (kde#455327)
  * Add "Get more Apps in Discover" button to kopenwithdialog
  * new worker API
  * Bump deprecation KF version in ecm_set_disabled_deprecation_versions
  * KPropertiesDialog: fix saving changes when editing a .desktop file symlink (kde#450727)
* Fri Jun 10 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.95.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.95.0
- Changes since 5.94.0:
  * KCoreUrlNavigator: add urlSelectionRequested signal (kde#453289)
  * kio_file: fix data race on static user cache (kde#454619)
  * file_unix: use thread id rather than pid for filehelper socket
  * [KDirOperator] Add option to show hidden files last
  * [KFileItemDelegate] Add a semi-transparent effect to the labels of hidden files
  * PreviewJob: Resolve parent mime types before checking wildcards (kde#453480)
  * [kemailclientlauncherjob] Allow setting BCC
  * TrashSizeCache: fix parsing of directory cachesize file and improve code
  * DirectorySizeJob: use targetUrl as url
  * KFileItem: GetStatusBarInfo: Improve display for urls
  * KDirModel: don't nuke query and fragment in URLs
  * [KFilePlacesView] Show inline eject button only for removable drives (kde#453890)
  * [KFilePlacesView] Don't show capacity bar for network shares
  * kpasswdserver: fix mistake
  * port to standard C++ smart pointers where possible
  * rfc search provider: Fix URL
  * Skip generation of KCM symlinks on windows
  * KCMs: Define plugin id to match the desktop file name
  * Embed json metadata in KCMs, port to new systemsettings namespaces
  * quickfix crash if element not found, we want to use the range erase here
  * Add env var KIO_ENABLE_WORKER_THREADS in case of trouble.
  * Initialize std::atomic<bool> variables.
  * SlaveBase: skip sighandlers when run in thread
  * kio_file: remove use of QDir::setCurrent()
  * Implement running KIO workers in-process using a thread
  * [StatJob] Set total amount to 1 Item
  * KSambashare: handle "Weak crypto is allowed" error message
  * dropjob: don't create PasteJob when `m_hasArkFormat` is true
  * KFileWidget: initialize KFilePlaceModel before KUrlNavigator
  * [previewjob] Deduplicate legacy plugins based on desktop file name instead of pluginId
* Tue May 10 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.94.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.94.0
- Too many changes since 5.93.0, only listing bugfixes:
  * KFileWidget: allow icon sizes to go up to 512 (kde#452139)
  * dropjob: Extract Ark data in ctor (kde#453390)
  * Don't put job/ioworker on hold after getting the mimetype (kde#452729)
  * [KUrlNavigatorPlacesSelector] Do storage setup also when requesting a new tab (kde#452923)
  * KFilePlacesView: use animations only if QStyle::SH_Widget_Animation_Duration > 0 (kde#448802)
  * KUrlNavigator: offer open in new window action too (kde#451809)
* Sun Apr  3 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.93.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.93.0
- Changes since 5.92.0:
  * Fix KRecentDocumentTest
  * fix reading wrong integer type from config (kde#452048)
  * Add Yandex search keywords
  * [KFilePlacesView] Don't append "(hidden)" to disappearing groups
  * Don't use KCrash on Android, currently not used there
  * KOpenWithDialog: alternative fix for the sort filter model regex
  * Introduce KCoreUrlNavigator
  * filewidgets: Auto-select filename before extension in filename dialog
  * Add support in krecentdocument to add to recently-used.xbel
  * [KFilePlacesView] Drop now unused placeEntered/Left handling
  * [KFilePlacesView] Show free space as permanent thin line
  * include QStandardPaths
  * autotests: port kdirmodeltest to QSignalSpy::wait
  * KRecentDocuments: don't save history for hidden files by default
  * KUrlNavigator: don't force LtR
  * [KPropertiesDialog] Use PlainText format for most labels
  * autotests: use temp dir to avoid issues with parallel tests
  * KFileItem: protect againt ' ' passed mimeType
  * KFileItem: use passed mimeType to determine isDir
  * KOpenWithDialog: Include arguments in name when writing a new desktop file
  * Add Android to the list of supported platforms
  * [KPropertiesDialog] Make read-only filename label selectable by mouse
  * [KFilePlacesModel] Improve outcome of dropped places
  * Add autotest for KDirLister::setMimeFilter
  * [ftp] Simplify code
* Mon Mar  7 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.92.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.92.0
- Too many changes since 5.91.0, only listing bugfixes:
  * KFilePlacesView: Fix crash when dragging over topmost section header (kde#450813)
  * Hide mount point labels if mount point can't be found (kde#449791)
  * Fix trash KCM not having any icon on wayland (kde#449859)
  * Fix potential crash in pastejob (kde#439948)
  * [KFilePlacesView] Mount place when dropping onto it (kde#206629)
  * [knewfilemenu] Bind stat job connection lifetime to dialog, not the whole menu (kde#433347)
* Mon Feb  7 2022 Christophe Giboudeaux <christophe@krop.fr>
- Force PIE when building with gcc-10 (boo#1195628)
* Sun Feb  6 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.91.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.91.0
- Too many changes since 5.90.0, only listing bugfixes:
  * Consider slow files as remote files in previewjob (kde#349161)
  * [desktopexecparser] Consider associations from mimeapps.list to
    determine whether an app supports a scheme (kde#440062)
  * [kopenwithdialog] Fix filtering (kde#449330)
  * kdirmodel: Allow using full path for Icon in .desktop file (kde#448116)
  * file_unix: Do not try to preserve ownership when permission is -1 (kde#447779)
  * KPropertiesDialog: use the KFileItem when checkig if the url is local (kde#444624)
* Mon Jan  3 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.90.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.90.0
- Too many changes since 5.89.0, only listing bugfixes:
  * kdirmodel: Return "unknown" icon when the icon is null (kde#447573)
  * do not access service past its prime (kde#446539)
* Sat Dec  4 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.89.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.89.0
- Changes since 5.88.0:
  * Add new signals and logic to handle open directories in new windows or tabs
  * Fix KRun::runApplication when xdg activation is involved (kde#446272)
  * Explicitly remove the event filters in classes managed by a unique_ptr
  * [KACLEditWidget] Load list of users/groups on demand
  * [KPropertiesDialog] Reuse existing KUser instance
  * Fix directory thumbnailer loading
  * [CopyJob] Emit moving while renaming
  * [KPropertiesDialog] Improve presentation of file type configuration
  * [KPropertiesDialog] Add extra fields value in correct column
  * Allow loading of Thumbnailers using embedded json metadata
  * KDirOperator: get the icon sizes from user settings
  * [KACLEditWidget] Remove redundancy and add icons to buttons
  * [KPropertiesDialog] Use Filelight icon and name from desktop file
  * [KPropertiesDialog] Hide time labels in multiple mode
  * [KPropertiesDialog] Also hide label_left for timestamps
  * Fix copying between different filesystems on Linux < 5.3
  * [KDynamicJobTracker] Support KUiServerV2JobTracker
- Drop patch, now upstream:
  * 0001-Fix-KRun-runApplication-when-xdg-activation-is-invol.patch
* Thu Dec  2 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Add patch to fix KRun on Wayland (kde#446272,
  gh#openSUSE/kmozillahelper#33):
  * 0001-Fix-KRun-runApplication-when-xdg-activation-is-invol.patch
* Sun Nov  7 2021 Christophe Giboudeaux <christophe@krop.fr>
- Strip 'Source' URL for faster submissions
* Sun Nov  7 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.88.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.88.0
- Too many changes since 5.87.0, only listing bugfixes:
  * KMountPoint: revert to parsing /dev/disk/by-{uuid,label}/ manually (kde#442106)
  * CopyJob: handle the no-op case of symlinks on FAT partitions (kde#442310)
  * KUrlCompletion: Disregard the trailing slash when sorting directory paths (kde#442717)
  * KFilePropsPlugin: Allow to edit properties when setFileNameReadOnly is set (kde#441847)
  * kuriikwsfiltereng: Fix quitting match logic if accidentally bang syntax is used (kde#437660)
  * file_unix: Fix endless loop during xattr copy. (kde#441446)
  * Improve "trash is full" error message (kde#442865)
* Sun Oct  3 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.87.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.87.0
- Too many changes since 5.86.0, only listing bugfixes:
  * KUrlCompletion blocks autosuggestion from happening if the
    input is an exact directory path. (kde#420966)
  * KDirOperator: provide an option to enable showing open-with item actions (kde#440748)
  * Fix permissions when copying files (kde#404777)
  * KFileItem: refresh() shouldn't discard ACL attributes (kde#299155)
  * KPropertiesDialog: show text label with item name for readonly items too (kde#442237)
* Wed Sep 15 2021 Christophe Giboudeaux <christophe@krop.fr>
- Drop the unneeded baselibs.conf.
* Mon Sep  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.86.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.86.0
- Too many changes since 5.85.0, only listing bugfixes:
  * Inline kssld operators to avoid duplicate symbol errors (kde#428807)
  * KFilePlaceEditDialog: Always preserve previous icon (kde#439622)
  * kio_http: wrap a long error message (kde#160399)
  * kio_file: detect failure to create symlinks due to filesystem support (kde#253678)
  * CopyJob: ask users about replacing invalid characters in file/folder names (kde#136746)
  * KDirOperator: expand to url only in detail tree view (kde#440475)
* Fri Aug 27 2021 Christophe Giboudeaux <christophe@krop.fr>
- Disable lto for ppc64 builds.
* Sat Aug 21 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Move the designer plugin to the main package, it's used in
  applications like KMail through QFormBuilder
* Fri Aug  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.85.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.85.0
- Too many changes since 5.84.0, only listing bugfixes:
  * Message dialogs: wrap the text (kde#440545)
  * Fix creating thumbnails for items under desktop:/ (kde#438691)
  * KPropertiesDialog: fix applying permissions recursively (kde#225658)
* Sun Jul  4 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.84.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.84.0
- Too many changes to list here.
- Only install the license files once
* Sat Jun  5 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.83.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.83.0
- Too many changes since 5.82.0, only listing bugfixes:
  * KOpenWithDialog: expand category on selection (kde#437885)
  * [kopenwithdialog] Show better error message when specifying a non-executable file (kde#437880)
  * [KCoreDirLister] Guard uiDelegate(), it might be null (kde#437153)
  * Allow selecting directories in KFileWidget (kde#419874)
  * When finding a job delegate extension, also try the uiDelegate() of its parents (kde#436049)
  * PreviewJob: Create a larger SHM when necessary (kde#430862)
- Remove patches:
  * 0001-MimeTypeFinderJob-Resolve-symlinks-for-a-local-file.patch
  * 0002-MimeTypeFinderJob-the-StatJob-details-should-include.patch
  * 0003-kio_file-pass-the-absolute-path-to-QMimeDatabase-mim.patch
* Fri May 14 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Add patches to fix issues with MimeTypeFinderJob (kde#398908):
  * 0001-MimeTypeFinderJob-Resolve-symlinks-for-a-local-file.patch
  * 0002-MimeTypeFinderJob-the-StatJob-details-should-include.patch
  * 0003-kio_file-pass-the-absolute-path-to-QMimeDatabase-mim.patch
* Thu May  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Drop 0001-PreviewJob-Create-a-larger-SHM-when-necessary.patch.
  Merged in kio 5.82.
* Tue May  4 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Add patch to fix thumnail creation in certain conditions (kde#430862):
  * 0001-PreviewJob-Create-a-larger-SHM-when-necessary.patch
* Sat May  1 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.82.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.82.0
- Too many changes since 5.81.0, only listing bugfixes:
  * Make the openOrExecute dialog modal (kde#430396)
  * KDirOperator: show the progress bar above the horizontal scrollbar
    (kde#194017)
* Mon Apr  5 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.81.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.81.0
- Too many changes since 5.80.0, only listing bugfixes:
  * Handle .theme files correctly (kde#435176)
  * PreviewJob: Initialize cachesSize with 0, only pass size > 0
    to shmget, improve createThumbnail (kde#430862)
  * KNewFileMenu: use destination side to stat destination (kde#429541)
- Drop patch:
  * 0001-MimeTypeFinderJob-don-t-put-job-on-hold-for-local-fi.patch
* Tue Mar 23 2021 Christophe Giboudeaux <christophe@krop.fr>
- Add patch to prevent file.so from remaining loaded (kde#434455, boo#1183880)
  * 0001-MimeTypeFinderJob-don-t-put-job-on-hold-for-local-fi.patch
* Mon Mar 15 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.80.1
  * Fix crash in ApplicationLauncherJob(service) when service is null.
* Sun Mar  7 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.80.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.80.0
- Too many changes since 5.79.0, only listing bugfixes:
  * PreviewJob: consider file size for cache invalidation (kde#433127)
  * RenameDialog: fix a potential buffer overflow (kde#432610)
* Mon Feb  8 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.79.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.79.0
- Too many changes since 5.78.0, only listing bugfixes:
  * Fix default codec being set to "US-ASCII" in KIO apps (kde#432406)
  * CopyJob: fix crash with skip/retry (kde#431731)
  * Fix lockup when renaming a file from properties dialog (kde#431902)
  * Tweak KFileWidget::slotOk logic when in files+directory mode (kde#431454)
* Wed Jan  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.78.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.78.0
- Too many changes since 5.77.0, only listing bugfixes:
  * Remove knetattach item from the remote:// ioslave's view (kde#430211)
  * RenameDialog: Add missing nullptr initialization (kde#430374)
  * KFileItemActions: fix condition, we want to exclude only remote dirs (kde#430293)
  * KUrlNavigator: resolve relative dir paths (kde#319700)
  * KFileWidget: allow files that begin with a ':' to be selected (kde#322837)
  * KFilePlacesView: allow setting a static icon size (kde#182089)
  * KFileItemActions: add new method to insert openwith actions (kde#423765)
- Drop 0001-RenameDialog-Add-missing-nullptr-initialization.patch
* Tue Dec 22 2020 Luca Beltrame <lbeltrame@kde.org>
- Add upstream patch to prevent crashing when using "apply to all"
  in the move/copy/overwrite dialog (kde#430374):
  * 0001-RenameDialog-Add-missing-nullptr-initialization.patch
* Sat Dec  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.77.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.77.0
- Too many changes since 5.76.0, only listing bugfixes:
  * NewFile Dialog: allow to accept directory creation before stat has run (kde#429838)
  * KUrlNavBtn: make opening subdirs from dropdown menu with the keyboard work (kde#428226)
  * Places view: highlight place only when it is displayed (kde#429806)
  * KIO::iconNameForUrl: resolve icon for remote files based on name (kde#429530)
  * RenameDialog: allow to overwrite when files are older (kde#236884)
  * Do not add unnecessary separators (kde#427830)
* Sat Nov  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.76.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.76.0
- Too many changes since 5.75.0, only listing bugfixes:
  * CopyJob: don't count skipped files in the notification (kde#417034)
  * FileWidget: Show Selected file preview on mouse leave (kde#418655)
  * Add bookmarks for pictures, music and videos (kde#427876)
  * kfilewidget: keep the text in the Name box when navigating (kde#418711)
  * KFilePlacesModel: ignore hidden places when computing closestItem (kde#426690)
  * kio_trash: fix the logic when no size limit is set (kde#426704)
* Mon Oct  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.75.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.75.0
- Too many changes since 5.74.0, only listing bugfixes:
  * kio_trash: remove unnecessarily strict permission check (kde#76380)
  * OpenUrlJob: handle all text scripts consistently (kde#425829)
  * KDirOperator: don't call setCurrentItem on an empty url (kde#425163)
  * KNewFileMenu: fix creating new dir with name starting with ':' (kde#425396)
  * Allow double quotes in filenames in KFileWidget (kde#185433)
  * StatJob: cancel job if url is invalid (kde#426367)
- Drop upstream patches:
  * 0001-Remove-old-kio_fonts-hack-in-KCoreDirLister-hostname.patch
  * 0002-KUrlCompletion-accommodate-local-protocols-that-use-.patch
* Sun Sep 13 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Add patches to fix browsing kdeconnect://:
  * 0001-Remove-old-kio_fonts-hack-in-KCoreDirLister-hostname.patch
  * 0002-KUrlCompletion-accommodate-local-protocols-that-use-.patch
* Sun Sep  6 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.74.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.74.0
- Too many changes since 5.73.0, only listing bugfixes:
  * Revert "[KUrlCompletion] Don't append / to completed folders" (kde#425387)
  * Update help text for editing the app command in a .desktop entry to comply with current spec. (kde#425145)
  * [filewidgets] Fix KUrlNavigatorButton padding on breadcrumb (kde#425570)
  * KFileWidget: reparse config to grab dirs added by other instances of the app (kde#403524)
  * Avoid systemd launched applications from closing forked children (kde#425201)
* Sun Aug  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.73.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.73.0
- Too many changes since 5.72.0, only listing bugfixes:
  * RenameDialog: Show if files are identical (kde#412662)
  * [rename dialog] Port Overwrite button to KStandardGuiItem::Overwrite (kde#424414)
  * Show up to three file item actions inline, not just one (kde#424281)
  * [Properties] Add SHA512 algorithm to checksums widget (kde#423739)
  * [WebDav] Fix copies that include overwrites for the webdav slave (kde#422238)
* Sun Jul  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.72.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.72.0
- Includes patch to fix running files with spaces in the path
  (boo#1174141, kde#423412, kde#423645)
- Includes patch to fix copying to protocols which don't always
  report available space (boo#1174169)
- Too many changes to list here.
* Sun Jun  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.71.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.71.0
- Too many changes to list here.
- Drop upstream patches:
  * Fix-service-file-specifying-Run-in-terminal-giving-error.patch
  * CopyJob-Check-if-destination-dir-is-a-symlink.patch
* Mon May 18 2020 Antonio Larrosa <alarrosa@suse.com>
- Add kded as a required package since kio calls org.kde.kded5 via dbus
* Fri May 15 2020 Wolfgang Bauer <wbauer@tmo.at>
- Add Fix-service-file-specifying-Run-in-terminal-giving-error.patch
  to fix starting services that use "Run in terminal" (kde#421374)
- Add CopyJob-Check-if-destination-dir-is-a-symlink.patch to fix
  copying files to symlinked folders (kde#421213)
* Sun May  3 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.70.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.70.0
- Too many changes since 5.69.0, only listing bugfixes:
  * [RenameDialog] Add an arrow indicating direction from src to dest (kde#268600)
  * Make the HTML file template more useful (kde#419935)
  * kio_trash: Add size, modification, access and create date for trash:/ (kde#413091)
  * Show previews on encrypted filesystems (kde#411919)
  * [KPropertiesDialog] Disable changing remote dir icons (kde#205954)
* Sun Apr  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.69.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.69.0
- Too many changes since 5.68.0, only listing bugfixes:
  * FileWidgets: Ignore Return events from KDirOperator (kde#412737)
  * [KNewFileMenu] Add extension to proposed filename (kde#61669)
  * [DesktopExecParser] Open {ssh,telnet,rlogin}:// urls with ktelnetservice (kde#418258)
* Sun Mar  8 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.68.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.68.0.php
- Too many changes since 5.67.0, only listing bugfixes:
  * [KFileFilterCombo] Don't add invalid QMimeType to mimes filter (kde#417355)
  * Fix running konsole on Wayland (kde#408497)
  * KIO::iconNameForUrl: fix searching for kde protocol icons (kde#417922)
  * Change "AutoSkip" to "Skip All" (kde#416964)
  * [KOpenWithDialog] Automatically select the result if the model filter has only one match (kde#400725)
* Sun Feb  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Replace %%make_jobs with %%cmake_build.
* Sun Feb  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.67.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.67.0.php
- Too many changes since 5.66.0, only listing bugfixes:
  * Allow to handle apps with Terminal=True in their desktop
    file, handle their associated mimetype properly (kde#410506)
  * Add KIO::DropJobFlag to allow manually showing the menu (kde#415917)
  * [KOpenWithDialog] Hide collapsible group box when all
    options inside are hidden (kde#415510)
  * SlaveBase::dispatchLoop: Fix timeout calculation (kde#392768)
  * [KDirOperator] Allow renaming files from the context menu (kde#189482)
* Sun Jan  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.66.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.66.0.php
- Too many changes since 5.65.0, only listing bugfixes:
  * Adding support for mounting KIOFuse URLs for applications that don't use KIO (kde#398216)
  * [KUrlNavigator] Add RPM support to krarc: (kde#408082)
  * KFilePlaceEditDialog: fix crash when editing the Trash place (kde#415676)
* Sun Dec  8 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.65.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.65.0.php
- Too many changes since 5.64.0, only listing bugfixes:
  * [KFileWidget] Avoid calling slotOk right after the url changed (kde#412737)
  * KRun: don't override user preferred app when opening local *.*html and co. files (kde#399020)
  * [KPropertiesDialog] provide a way of showing the target of a symlink (kde#413002)
  * [Remote ioslave] Add Display Name to remote:/ (kde#414345)
  * Fix HTTP proxy settings (kde#414346)
  * [DeleteJob] Use a separate worker thread to run actual IO operation (kde#390748)
  * [KPropertiesDialog] Make creation date string mouse-selectable too (kde#413902)
* Sun Nov  3 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.64.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.64.0.php
- Too many changes since 5.63.0, only listing bugfixes:
  * Treat "application/x-ms-dos-executable" as executable on all platforms (kde#412694)
- Drop kio-5.63.0-fix-depth-with-kdav.patch. Merged upstream.
* Wed Oct 23 2019 Matthias Fehring <buschmann23@opensuse.org>
- Fix nextcloud calendar content not visible (kde#413316)
  * kio-5.63.0-fix-depth-with-kdav.patch
* Sun Oct  6 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.63.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.63.0.php
- Too many changes since 5.62.1, only listing bugfixes:
  * Fix crash on exit in kio_file (kde#408797)
  * [KUrlNavigatorPlacesSelector] Properly identify teardown action (kde#403454)
  * KCoreDirLister: fix crash when creating new folders from kfilewidget (kde#401916)
  * [Advanced Permissions] Fix icon names (kde#411915)
* Tue Sep 17 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.62.1
  * Fixed interaction with DOS/Windows executables in KRun::runUrl
* Sat Sep  7 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.62.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.62.0.php
- Changes since 5.61.0:
  * [CopyJob] Use resolved URL in copyingDone so undo can rename back using local file (kde#391606)
  * FileUndoManager: improve debugging facilities
  * kio_trash: split up copyOrMove, for a better error than "should never happen"
  * FileUndoManager: clearer assert when forgetting to record
  * Fix exit and crash in kio_file when put() fails in readData.
  * autotests: use QVERIFY2 to print the job error if exec() fails
  * [CopyJob] Fix crash when copying an already existing dir and pressing "Skip" (kde#408350)
  * [KUrlNavigator] Add MIME types supported by krarc to isCompressedPath (kde#386448)
  * Added dialog to set execute permission for executable file when trying to run it.
  * [KPropertiesDialog] Always check mount point being null (kde#411517)
  * [KRun] Check mime type for isExecutableFile first
  * Add an icon for the trash root and a proper label
  * Add support for handling QNAM SSL errors to KSslErrorUiData
  * Making FileJob behave consistently.
  * assert slave command finality
  * [KFilePlacesView] Use asynchronous KIO::FileSystemFreeSpaceJob
  * rename internal 'kioslave' helper executable to 'kioslave5' (kde#386859)
  * [KDirOperator] Middle-elide labels that are too long to fit
  * [KDirOperator] Add follow new directories options
  * KDirOperator: Only enable "Create New" menu if the selected item is a directory
  * KIO FTP: Fix file copy hanging when copying to existing file
  * KIO: port to non-deprecated KWindowSystem::setMainWindow
  * KRun: fix runtime warning when widget is null
  * KRun: remove KProcessRunner dependency on QtWidgets
  * Port KIO::Job documentation to Qt5-style connect syntax
  * Make file bookmark names consistent
  * Remove unused includes
  * Add option to build Qt Designer plugin (BUILD_DESIGNERPLUGIN, default ON)
  * [KDirOperator] Use more human-readable sort order descriptions
  * Fix build by removing obsolete qrc file for newly-removed images
  * [Permissions editor] Port icons to use QIcon::fromTheme() (kde#407662)
- Replace foo-devel with cmake(KF5Foo) in build requirements
* Wed Aug  7 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.61.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.61.0.php
- Changes since 5.60.0:
  * Remove explicit use of ECM_KDE_MODULE_DIR, is part of ECM_MODULE_PATH
  * Use identical internet-services icon.
  * Stabilize test KFileWidgetTest::testDropFile
  * Add missing KIOWIDGETS_NO_DEPRECTAED check
  * Deprecate suggestName
  * Replace implementation of suggestName with KFileUtils::suggestName
  * Port internal usage of KIO::suggestName
  * Fix can't enter directory error on some FTP servers with Turkish locale (kde#409740)
  * Port from KRun::runService to KRun::runApplication
  * Fix compiler warnings about initialization order.
  * Look for protocols in the bin dir too, to fix the autotests
* Fri Jul 19 2019 Wolfgang Bauer <wbauer@tmo.at>
- Don't lower minimum Qt version anymore, it requires 5.11 now
- Drop conditionals for no longer supported openSUSE versions
* Sun Jul 14 2019 lbeltrame@kde.org
- Update to 5.60.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.60.0.php
- Changes since 5.59.0:
  * Fix KFileItemTest::testIconNameForUrl test to reflect different icon name
  * Fix i18n number-of-arguments error in knewfilemenu warning message
  * [ftp] Fix wrong access time in Ftp::ftpCopyGet()
  * [CopyJob] Batch reporting processed amount
  * [CopyJob] Report results after finishing copy (kde#407656)
  * Move redundant logic in KIO::iconNameForUrl() into KFileItem::iconName() (kde#356045)
  * Install KFileCustomDialog
  * [Places panel] Don't show Root by default
  * Downgrade "Could not change permissions" dialog box to a qWarning
  * O_PATH is only available on linux. To prevent the compiler from throwing an error due to it's absence fallback to O_RDONLY.
  * Show feedback inline when creating new files or folders
  * Auth Support: Drop privileges if target is not owned by root
  * [copyjob] Only set modification time if the kio-slave provided it (kde#374420)
  * Cancel privilege operation for read-only target with the current user as owner
  * Install in new logging directory when we use kf5 5.59.0
  * Add KProtocolInfo::defaultMimetype
  * Always save view settings when switching from one view mode to another
  * Restore exclusive group for sorting menu items
  * Dolphin-style view modes in the file dialog (kde#86838)
  * kio_ftp: improve error handling when copying to FTP fails
  * kioexec: change the scary debug messages for delayed deletion
- Dropped patches, now upstream:
  * copyjob-Only-set-modification-time-if-the-kio-slave-provided-it.patch
* Wed Jun 26 2019 wbauer@tmo.at
- Add upstream patch to fix downloaded files (via http) getting an
  "invalid" modification time (boo#1104595, kde#374420)
  * copyjob-Only-set-modification-time-if-the-kio-slave-provided-it.patch
* Sun Jun  9 2019 lbeltrame@kde.org
- Update to 5.59.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.59.0.php
- Changes since 5.58.0:
  * Manipulate bytes instead of characters
  * Fix kioslave executables never exiting, when setting KDE_FORK_SLAVES.
  * Fix desktop link to file or directory (kde#357171)
  * Test current filter before setting a new one (kde#407642)
  * [kioslave/file] Add a codec for legacy filenames
  * Rely upon QSysInfo to retrieve the system details
  * Add Documents to the default list of Places
  * KIO: port away from QSslSocket+QFileInfo deprecated API
  * kioslave: preserve argv[0], to fix applicationDirPath() on non-Linux
  * KOpenWith: port away from deprecated QModelIndex::child()
  * autotests: update host after www.davidfaure.fr breakage
  * Allow to drop one file or one folder on KDirOperator (kde#45154)
  * Truncate long filname before creating a link (kde#342247)
  * Remove deprecated method qVariantFromValue->QVariant::fromValue
* Wed May 15 2019 lbeltrame@kde.org
- Update to 5.58.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.58.0.php
- Changes since 5.57.0:
  * [FileWidget] Replace "Filter:" with "File type:" when saving with a limited list of mimetypes (kde#79903)
  * use actually existing breeze icon for the new file Program.desktop
  * Reword some text, a couple clean ups, add a separator
  * autotests: adapt to QUrl behaviour change in Qt 5.12.1
  * autotests: adapt to shared-mime-info change
  * Use regular stat when resolving a symlink
  * autotests: kfileitemtest: close file before inspecting it
  * [Properties dialog] Use the string "Free space" instead of "Disk usage" (kde#406630)
  * Remove TODO
  * Truncate trailing forward slashes(/)
  * Fix signed/unsigned warning after statx change
  * Fill UDSEntry::UDS_CREATION_TIME under linux when glibc >= 2.28
  * [KUrlNavigator] Fix URL navigation when exiting archive with krarc and Dolphin (kde#386448)
  * [KDynamicJobTracker] When kuiserver isn't available, also fall back to widget dialog (kde#379887)
* Sun Apr 14 2019 lbeltrame@kde.org
- Update to 5.57.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.57.0.php
- Changes since 5.56.0:
  * Too many changes to list here
- Dropped patches, now upstream:
  * Fix-NTFS-hidden-check-for-symlinks.patch
* Sun Mar 10 2019 lbeltrame@kde.org
- Update to 5.56.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.56.0.php
- Changes since 5.55.0:
  * Port deprecated methods
  * kioexec: KAboutData::setupCommandLine() already sets help & version
  * Fix crash in Dolphin when dropping trashed file in trash (kde#378051)
  * Use correct prefix for static variable
  * Middle-elide very long filenames in error strings (kde#404232)
  * Add support for portals in KRun
  * [KPropertiesDialog] Fix group combobox (kde#403074)
  * properly attempt to locate the kioslave bin in $libexec AND $libexec/kf5
  * Use AuthCore instead of Auth
  * Add icon name to service providers in .desktop file
  * Read IKWS search provider icon from desktop file
  * [PreviewJob] Also pass along that we're the thumbnailer when stat'ing file
* Sun Mar  3 2019 wbauer@tmo.at
- Add Fix-NTFS-hidden-check-for-symlinks.patch to avoid hiding
  symlinks to NTFS mountpoints (kde#402738)
* Fri Feb 15 2019 alarrosa@suse.com
- Downgrade the Qt version requirement to build with 5.9
* Sun Feb 10 2019 lbeltrame@kde.org
- Update to 5.55.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.55.0.php
- Changes since 5.54.0:
  * Improve keyboard controls of the checksum widget
  * Add helper function to disable redirections (useful for kde-open)
  * Correct tag
  * Revert "Refactor SlaveInterface::calcSpeed" (kde#402665)
  * Revert "Fix elapsed time check"
  * NetRC: Delete copy constructor and assignment operator
  * KPasswdServerClient: Delete copy constructor and assignment operator
  * KSSLSettings: Delete copy constructor and assignment operator
  * delete copy constructor and assignment operator of some internal classes
  * Fix elapsed time check
  * Don't set CMake policy CMP0028 to old. We don't have targets with :: unless they are imported...
  * [kio] Add ellipsis to search label in Cookies section
  * [KNewFileMenu] Don't emit fileCreated when creating a directory
  * Use (and suggest using) the nicer K_PLUGIN_CLASS_WITH_JSON
  * avoid blocking kio_http_cache_cleaner and ensure exit with session (kde#367575)
  * Fix failing knewfilemenu test and underlying reason for its failure
- Dropped patches, now upstream:
  * 0002-Revert-Refactor-SlaveInterface-calcSpeed.patch
* Mon Jan 14 2019 lbeltrame@kde.org
- Update to 5.54.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.54.0.php
- Changes since 5.53.0:
  * Too many changes to list here
- Add upstream patch to prevent crashes in KIO (kde#402665)
  * 0002-Revert-Refactor-SlaveInterface-calcSpeed.patch
* Sun Dec  9 2018 lbeltrame@kde.org
- Update to 5.53.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.53.0.php
- Changes since 5.52.0:
  * Too many changes to list here
* Sun Nov 11 2018 lbeltrame@kde.org
- Update to 5.52.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.52.0.php
- Changes since 5.51.0:
  * Too many changes to list here
- Dropped patches, now upstream:
  * 0001-kio_help-Fix-crash-in-QCoreApplication-when-accessin.patch
* Thu Oct 18 2018 Fabian Vogt <fabian@ritter-vogt.de>
- Add patch to fix kio_help crashing on start:
  * 0001-kio_help-Fix-crash-in-QCoreApplication-when-accessin.patch
* Tue Oct 16 2018 Luca Beltrame <lbeltrame@kde.org>
- Run spec-cleaner
* Mon Oct 15 2018 lbeltrame@kde.org
- Update to 5.51.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.51.0.php
- Changes since 5.50.0:
  * Too many changes to list here
* Thu Sep 13 2018 lbeltrame@kde.org
- Update to 5.50.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.50.0.php
- Changes since 5.49.0:
  * Too many changes to list here
- Drop 0001-Revert-Support-NTFS-hidden-files.patch, the problem
  with the root folder being hidden has been fixed (or rather
  workarounded) upstream
* Sun Aug 19 2018 christophe@krop.fr
- Update to 5.49.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.49.0.php
- Changes since 5.48.0:
- Too many changes to list here
* Mon Jul 16 2018 lbeltrame@kde.org
- Update to 5.48.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.48.0.php
- Changes since 5.47.0:
  * Too many changes to list here
- Refreshed patches:
  * 0001-Revert-Support-NTFS-hidden-files.patch
* Wed Jun 13 2018 lbeltrame@kde.org
- Update to 5.47.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.47.0.php
- Changes since 5.46.0:
  * Check if destination exists also when pasting binary data (kde#394318)
  * Auth support: Return the actual length of socket buffer
  * Auth support: Unify API for file descriptor sharing
  * Auth support: Create socket file in user's runtime directory
  * Auth support: Delete socket file after use
  * Auth support: Move task of cleaning up socket file to FdReceiver
  * Auth support: In linux don't use abstract socket to share file
    descriptor
  * [kcoredirlister] Remove as many url.toString() as possible
  * KFileItemActions: fallback to default mimetype when selecting only files
    (kde#393710)
  * Introduce KFileItemListProperties::isFile()
  * KPropertiesDialogPlugin can now specify multiple supported protocols
    using X-KDE-Protocols
  * Preserve fragment when redirecting from http to https
  * [KUrlNavigator] Emit tabRequested when path in path selector menu is
    middle-clicked
  * Performance: use the new uds implementation
  * Don't redirect smb:/ to smb:// and then to smb:///
  * Allow accepting by double-click in save dialog (kde#267749)
  * Enable preview by default in the filepicker dialog
  * Hide file preview when icon is too small
  * i18n: use plural form again for plugin message
  * Use a regular dialog rather than a list dialog when trashing or deleting
    a single file
  * Make the warning text for deletion operations emphasize its permanency
    and irreversibility
  * Revert "Show view mode buttons in the open/save dialog's toolbar"
* Fri Jun  1 2018 lbeltrame@kde.org
- Don't recommend kio-extras5
* Sun May 13 2018 lbeltrame@kde.org
- Update to 5.46.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.46.0.php
- Changes since 5.45.0:
  * Too many changes to list here
- Refreshed patches:
  * 0001-Revert-Support-NTFS-hidden-files.patch
* Fri May  4 2018 wbauer@tmo.at
- Add 0001-Revert-Support-NTFS-hidden-files.patch to revert the new
  support for NTFS hidden files, it caused the mount point itself
  to be hidden (boo#1091780, kde#392913)
* Sat Apr 14 2018 lbeltrame@kde.org
- Update to 5.45.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.45.0.php
- Changes since 5.44.0:
  * Too many changes to list here
* Mon Mar 12 2018 lbeltrame@kde.org
- Update to 5.44.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.44.0.php
- Changes since 5.43.0:
  * Too many changes to list here
- Dropped patches, now upstream:
  * 0001-Dont-stat-etc-localtime-between-read-and-write.patch
  * 0001-Fix-bug-382437-Regression-in-kdialog-causes-wrong-file-ext.patch
* Tue Feb 13 2018 alarrosa@suse.com
- Add patch to fix a problem that made kio copy files too slowly (kde#384561)
  * 0001-Dont-stat-etc-localtime-between-read-and-write.patch
- Add patch to fix kdialog writing files with .bin extension in chrome
  when downloading files (kde#382437)
  * 0001-Fix-bug-382437-Regression-in-kdialog-causes-wrong-file-ext.patch
* Mon Feb 12 2018 lbeltrame@kde.org
- Update to 5.43.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.43.0.php
- Changes since 5.42.0:
  * Too many changes to list here
- Dropped patches, now upstream:
  * 0001-Fix-KFilePreviewGenerator-LayoutBlocker.patch
  * fix-overlap-of-first-item-in-kfileplacesview.patch
* Tue Jan 16 2018 lbeltrame@kde.org
- Update to 5.42.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.42.0.php
- Changes since 5.41.0:
  * Too many changes to list here
- Add upstream patch fix-overlap-of-first-item-in-kfileplacesview.patch:
  * Fixes overlapping in items in the places view
- Dropped patches, now upstream:
  * fix-handling-of-KCookieAdvice_AcceptForSession.patch
* Fri Jan 12 2018 fabian@ritter-vogt.de
- Add patch to fix layout of icons in the file dialog (kde#352776):
  * 0001-Fix-KFilePreviewGenerator-LayoutBlocker.patch
* Sun Dec 17 2017 lbeltrame@kde.org
- Update to 5.41.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.41.0.php
- Changes since 5.40.0:
  * Too many changes to list here
- Dropped patches, now upstream:
  * kio-5.40-fix-directory-creation.patch
* Thu Nov 30 2017 antoine.belvire@opensuse.org
- Fix error upon directory creation with Dolphin (kde#387073):
  * Add kio-5.40-fix-directory-creation.patch.
* Mon Nov 13 2017 lbeltrame@kde.org
- Update to 5.40.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.40.0.php
- Changes since 5.39.0:
  * Fix display of remote:/ in the qfiledialog
  * Implement support for categories on KfilesPlacesView
  * HTTP: fix error string for the 207 Multi-Status case
  * KNewFileMenu: clean up dead code, spotted by Coverity
  * IKWS: Fix possible infinite loop, spotted by Coverity.
  * KIO::PreviewJob::defaultPlugins() function
  * Revert "Add support for sharing file descriptor between file ioslave and it's KAuth helper"
  * Revert "Add kauth helper to file ioslave"
  * Revert "Add ability to use the new kauth helper in file ioslave"
  * Add ability to use the new kauth helper in file ioslave
  * Add kauth helper to file ioslave
  * Add support for sharing file descriptor between file ioslave and it's KAuth helper
* Thu Nov  2 2017 wbauer@tmo.at
- Add fix-handling-of-KCookieAdvice_AcceptForSession.patch to
  fix the "Accept For Session" cookie setting that was not properly
  respected (boo#1049975, kde#386325)
* Mon Oct 23 2017 lbeltrame@kde.org
- Update to 5.39.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.39.0.php
- Changes since 5.38.0:
  * kioexec: Watch the file when it has finished copying (kde#384500)
  * Make the string translatable
  * KFileItemDelegate: Always reserve space for icons (kde#372207)
  * Show kioslave names in the debug output
* Tue Sep 12 2017 lbeltrame@kde.org
- Update to 5.38.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.38.0.php
- Changes since 5.37.0:
  * Too many changes to list here
- Dropped patches, now upstream:
  * fix-applying-special-file-attributes.patch
  * KDesktopPropsPlugin-create-destination-dir.patch
  * Really-rate-limit-INF_PROCESSED_SIZE-messages.patch
* Tue Aug 22 2017 wbauer@tmo.at
- Add Really-rate-limit-INF_PROCESSED_SIZE-messages.patch to not
  cause high CPU load during file copies (kde#383843, boo#1016920,
  boo#1051349)
- Add KDesktopPropsPlugin-create-destination-dir.patch to fix
  modifying applications' .desktop files in the "Edit File Type"
  dialog if the corresponding directory doesn't exist in
  ~/.local/share/ (boo#1000946)
* Tue Aug 15 2017 wbauer@tmo.at
- Add fix-applying-special-file-attributes.patch to fix modifying
  advanced permissions in the file/folder properties dialog
  (boo#978935, kde#365795)
* Sat Aug 12 2017 christophe@krop.fr
- Update to 5.37.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.37.0.php
- Changes since 5.36.0 :
  * Fix assert in UrlUtil::firstChildUrl()
  * Add new method urlSelectionRequested to KUrlNavigator
  * Revert "Emit a "." UDSEntry when not present, even on empty directories."
  * KUrlNavigator: expose the KUrlNavigatorButton that received a drop event
  * Fix build on musl libc by exposing setgroups(2).
  * Emit a "." UDSEntry when not present, even on empty directories. (kde#382046)
  * Fix test not found when setting CMAKE_RUNTIME_OUTPUT_DIRECTORY, for some reason.
  * Stash without asking the user with a Copy/Cancel popup.
  * Ensure KDirLister updates items whose target URL has changed. (kde#382341)
  * Fix kdirwatch warning
  * API dox: use official name "D-Bus" consistently
  * Make advanced options of "open with" dialog collabsible and hidden by default
  * Minor: Fix a couple of deprecation warnings
* Wed Jul 12 2017 lbeltrame@kde.org
- Update to 5.36.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.36.0.php
- Changes since 5.35.0:
  * [KNewFileMenu] Hide "Link To Device" menu if it would be empty
  * Use KIO::rename instead of KIO::moveAs in setData (kde#380897, kde#380898)
  * Get the doc dirs with the newly exported function
  * Fix drop menu position on Wayland
  * KUrlRequester: Set NOTIFY signal to textChanged() for text property.
  * [KOpenWithDialog] HTML-escape file name
  * tests: dropjobtest: register KIO::CopyJob* as metatype
  * tests: fix krununittest when install prefix has spaces
  * [FEATURE] Option to build & install QCH file with the public API dox
  * KCoreDirLister::cachedItemForUrl: don't create the cache if it didn't exist
  * Use "data" as filename when copying data urls (kde#379093)
* Sun Jun 11 2017 lbeltrame@kde.org
- Update to 5.35.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.35.0.php
- Changes since 5.34.0:
  * Too many changes to list here
- Dropped patches, now upstream:
  * 0001-Identify-PIE-binaries-application-x-sharedlib-as-exe.patch
* Mon May 29 2017 fabian@ritter-vogt.de
- Add patch to allow running PIE enabled binaries (kde#350018):
  * 0001-Identify-PIE-binaries-application-x-sharedlib-as-exe.patch
* Mon May 15 2017 fabian@ritter-vogt.de
- Update to 5.34.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.34.0.php
- Changes since 5.33.0:
  * Fix quoting of preprocessor-definition.
  * KDirSortFilterProxyModel: bring back natural sorting (kde#343452)
  * Fill UDS_CREATION_TIME with the value of st_birthtime on FreeBSD
  * http slave: send error page after authorization failure (kde#373323)
  * kioexec: delegate upload to a kded module (kde#252026, kde#370532)
  * Fix KDirlister Gui Test setting URL scheme twice
  * Delete kiod modules on exit
  * Don't apply the workaround before Qt 5.8.0
  * Generate a moc_predefs.h file for KIOCore (kde#371721)
  * kioexec: fix support for --suggestedfilename
- Remove patches, now upstream:
  * enable-natural-sorting-in-KDirSortFilterProxyModel.patch
- Use %%find_lang --with-man --all-name
- Use %%kf5_find_htmldocs
* Sat Apr 15 2017 lbeltrame@kde.org
- Update to 5.33.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.33.0.php
- Changes since 5.32.0:
  * make remote file:// URL redirect to smb:// work again
  * Upgrade ECM and KF5 version requirements for 5.33.0 release.
  * keep query encoding when HTTP Proxy is used
  * Fix minor typos
  * User messages cleanup (and de-emphasize Konqueror)
  * Updated user agents (Firefox 52 ESR, Chromium 57)
  * Added plugin actions
  * Simple patch
  * autotest: comment why the SSE-disabling thing doesn't work (QTBUG-47566)
  * Handle/truncate url display string assigned to job description. Prevents large data: urls from being included in UI notifications.
  * Restore Cancel button shortcut
  * Upgrade KF5 version to 5.33.0.
  * Add KFileWidget::setSelectedUrl()
  * Fix KUrlRequester save mode by adding setAcceptMode REVIEW: 129986
  * With this change it is now possible to list multiple paths as defined via the command line.
* Wed Apr 12 2017 wbauer@tmo.at
- Add enable-natural-sorting-in-KDirSortFilterProxyModel.patch to
  use natural sorting by default in the KDE file dialog and
  gwenview, configurable via the "NaturalSorting" option in
  kdeglobals (boo#1033668, kde#343452)
* Mon Mar 20 2017 lbeltrame@kde.org
- Drop sanitize-url-for-proxy.patch, merged upstream
* Sun Mar 19 2017 lbeltrame@kde.org
- Update to 5.32.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.32.0.php
- Changes since 5.31.0:
  * Too many changes to list here
  * Commit translations from l10n-kf5
  * Cookies KCM: disable "delete" button when there is no current item
  * Use the new shared library exported by KDocTools
  * Upgrade ECM and KF5 version requirements for 5.32.0 release.
  * Sanitize URLs before passing them to FindProxyForURL
  * make sure the cancel action is last
  * kio_help: use doOutputBuffer and simplify unicodeError
  * rename support: emit proper URL in FileRenamed
  * fix rename support: keep trashId rather than expecting it as input
  * remote: remove unused include
  * remote: remove redundant check
  * remote: rename kded module to allow co-installability with plasma-workspace <= 5.9
  * remote: use QUrl::fromLocalFile()
  * remote: just check if file exists
  * remote: use QDir::mkpath() to create the remoteview folder
  * remote: drop Messages.sh
  * remote: use same debug category as other slaves
  * remote: use json protocol
  * remote: don't redefine TRANSLATION_DOMAIN
  * remote: slots -> Q_SLOTS
  * Import remote ioslave from plasma-workspace
  * Fix TODO. We depend on Qt 5.3 by now
  * kio_trash: implement renaming of toplevel files and dirs
  * [PreviewJob] Remove maximum size for local files by default
  * allow to add application actions on an open menu
  * Port another use of QDateTime to QElapsedTimer. With proper / 1000 this time :)
  * Fixup previous commit to slave.cpp, divide by 1000 was missing.
  * [autotest] KTcpSocketTest was racy and leaky => simplify, fix.
  * Port from QDateTime::currentDateTime() to QElapsedTimer
  * Upgrade KF5 version to 5.32.0.
  * Fix double export in already-exported class
  * deprecate DrawFrame, as discussed in https://git.reviewboard.kde.org/r/129921/
* Wed Mar  1 2017 fabian@ritter-vogt.de
- Add patch to fix security issue with proxy configuration (boo#1027520)
  * sanitize-url-for-proxy.patch
* Thu Feb  9 2017 hrvoje.senjan@gmail.com
- Update to 5.31.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.31.0.php
* Sun Jan  8 2017 hrvoje.senjan@gmail.com
- Update to 5.30.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.30.0.php
* Sun Dec  4 2016 hrvoje.senjan@gmail.com
- Update to 5.29.0
  * Ported to categorized logging
  * Fix compilation against WinXP SDK
  * Allow uppercase checksums matching in Checksums tab
    (kde#372518)
  * Never stretch the last (=date) column in the file dialog
    (kde#312747)
  * Import and update kcontrol docbooks for code in kio from
    kde-runtime master
  * [OS X] make KDE's trash use the OS X trash
  * SlaveBase: add documentation about event loops and
    notifications and kded modules
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.29.0.php
* Sat Nov  5 2016 hrvoje.senjan@gmail.com
- Update to 5.28.0
  * Fix HTTP date format sent by kio_http to always use the C locale
    (kde#372005)
  * KACL: fix memory leaks detected by ASAN
  * Fix memory leaks in KIO::Scheduler, detected by ASAN
  * Removed duplicate clear button (kde#369377)
  * Fix editing autostart entries when /usr/local/share/applications
    doesn't exist (kde#371194)
  * [KOpenWithDialog] Hide TreeView header
  * Sanitize the symlink name buffer size (kde#369275)
  * Properly finish DropJobs when triggered is not emitted
    (kde#363936)
  * ClipboardUpdater: fix another crash on Wayland (kde#359883)
  * ClipboardUpdater: fix crash on Wayland (kde#370520)
  * Support non integer scale factors in KFileDelegate (kde#366451)
  * kntlm: Distinguish between NULL and empty domain
  * Don't show overwrite dialog if file name is empty
  * kioexec: use friendly filenames
  * Fix focus ownership if url is changed before showing the widget
  * Major performance improvement when turning previews off in the
    file dialog (kde#346403)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.28.0.php
* Sun Oct  9 2016 hrvoje.senjan@gmail.com
- Update to 5.27.0
  * Fix KIO slaves using only tls1.0
  * Fix ABI break in kio
  * KFileItemActions: add addPluginActionsTo(QMenu *)
  * Show copy buttons only after checksum has been calculated
  * Add missing feedback when computing a checksum (kde#368520)
  * Fix KFileItem::overlays returning empty string values
  * Fix launching terminal .desktop files with konsole
  * Classify nfs4 mounts as probablySlow, like nfs/cifs/..
  * KNewFileMenu: show New Folder action shortcut (kde#366075)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.27.0.php
- Drop upstreamed 0001-Fix-kio-using-only-tls1.0.patch and
  Fix-launching-terminal-desktop-files-with-konsole.patch
* Sun Oct  9 2016 fabian@ritter-vogt.de
- Add 0001-Fix-kio-using-only-tls1.0.patch
* Wed Oct  5 2016 hrvoje.senjan@gmail.com
- Added Fix-launching-terminal-desktop-files-with-konsole.patch
  (kde#368949, boo#1003125)
* Tue Sep  6 2016 hrvoje.senjan@gmail.com
- Update to 5.26.0
  * KPropertiesDialog: remove warning note from docu,
    the bug is gone
  * [test program] resolve relative paths using QUrl::fromUserInput
  * KUrlRequester: fix error box when selecting a file and
    reopening the file dialog
  * Provide a fallback if slaves don't list the . entry
    (kde#366795)
  * Fix creating symlink over "desktop" protocol
  * KNewFileMenu: when creating symlinks use KIO::linkAs
    instead of KIO::link
  * KFileWidget: fix double '/' in path
  * KUrlRequester: use static connect() syntax, was inconsistent
  * KUrlRequester: pass window() as parent for the QFileDialog
  * Avoid calling connect(null, .....) from KUrlComboRequester
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.26.0.php
* Mon Aug  8 2016 wbauer@tmo.at
- Remove workaround to install "Create New" templates as actual
  files, the issues with using the embedded resource are fixed in
  5.25.0
* Sun Aug  7 2016 hrvoje.senjan@gmail.com
- Update to 5.25.0
  * Qt >= 5.5 is now required
  * Fix KIO::linkAs() to work as advertised, i.e.
    fail if dest already exists
  * Fix KIO::put("file:///path") to respect the umask (kde#359581)
  * Fix KIO::pasteActionText for null dest item and for empty URL
  * Add support for undoing symlink creation
  * GUI option to configure global MarkPartial for KIO slaves
  * Fix MaxCacheSize limited to 99 KiB
  * Add clipboard buttons to checksums tab
  * KNewFileMenu: fix copying template file from embedded resource
    (kde#359581)
  * KNewFileMenu: Fix creating link to application (kde#363673)
  * KNewFileMenu: Fix suggestion of new filename when file
    already exist in desktop
  * KNewFileMenu: ensure fileCreated() is emitted for
    app desktop files too
  * KNewFileMenu: fix creating symlinks with a relative target
  * KPropertiesDialog: simplify button box usage,
    fix behavior on Esc
  * KProtocolInfo: refill cache to find newly installed protocols
  * KIO::CopyJob: port to qCDebug
    (with its own area, since this can be quite verbose)
  * KPropertiesDialog: add Checksums tab
  * Clean url's path before initializing KUrlNavigator
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.25.0.php
* Wed Jul  6 2016 hrvoje.senjan@gmail.com
- Update to 5.24.0
  * KIO: add SlaveBase::openPasswordDialogV2 for better error
    checking, please port your kioslaves to it
  * Fix KUrlRequester opening file dialog in wrong directory
    (kde#364719)
  * Fix unsafe KDirModelDirNode* casts
  * Add cmake option KIO_FORK_SLAVES to set default value
  * ShortUri filter: fix filtering of mailto:user@host
  * Add OpenFileManagerWindowJob to highlight file within a folder
  * KRun: add runApplication method
  * Add soundcloud search provider
  * Fix an alignment issue with the OS X native "macintosh" style
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.24.0.php
* Mon Jun  6 2016 hrvoje.senjan@gmail.com
- Update to 5.23.0
  * Give clearer error message when KRun(URL) is given a URL
    without scheme (kde#363337)
  * Add KProtocolInfo::archiveMimetypes()
  * Use selected icon mode in file open dialog sidebar
  * kshorturifilter: fix regression with mailto: not prepended
    when no mailer is installed
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.23.0.php
* Sat May  7 2016 hrvoje.senjan@gmail.com
- Update to 5.22.0 (boo#980066)
  * kurlnavigatortoolbutton.cpp - use buttonWidth in paintEvent()
  * New file menu: filter out duplicates (e.g. between .qrc and
    system files) (kde#355390)
  * Fix error message on startup of the cookies KCM
  * Remove kmailservice5, it can only do harm at this point
    (kde#354151)
  * Fix KFileItem::refresh() for symlinks. The wrong size, filetype
    and permissions were being set
  * Fix regression in KFileItem: refresh() would lose the file type,
    so a dir became a file (kde#353195)
  * Set text on QCheckbox widget rather than using a separate label
    (kde#245580)
  * Don't enable acl permissions widget if we don't own the file
    (kde#245580)
  * Fix double-slash in KUriFilter results when a name filter is set
  * KUrlRequester: add signal textEdited (forwarded from QLineEdit)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.22.0.php
* Mon Apr  4 2016 hrvoje.senjan@gmail.com
- Update to 5.21.0 (boo#974793)
  * FavIconsCache: sync after write, so other apps see it,
    and to avoid crash on destruction
  * Fix many threading issues in KUrlCompletion
  * Fix crash in rename dialog (360488)
  * KOpenWithDialog: improve window title and description text
    (359233)
  * Allow for better cross-platform deployment of io slaves by
    bundling protocol info in plugin meta data
  * Upgrade Qt version requirement to 5.4.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.21.0.php
- Drop upstreamed 0001-Fix-crash-in-rename-dialog.patch
* Thu Mar 17 2016 hrvoje.senjan@gmail.com
- Added 0001-Fix-crash-in-rename-dialog.patch (kde#360488)
* Sun Mar  6 2016 hrvoje.senjan@gmail.com
- Update to 5.20.0 (boo#970856)
  * Fix KIO app-slave connection breaking if appName contains
    a '/' (kde#357499)
  * Try multiple authentication methods in case of failures
  * help: fix mimeType() on get()
  * KOpenWithDialog: show mimetype name and comment in "Remember"
    checkbox text (kde#110146)
  * A series of changes to avoid a directory relist after a file
    rename in more cases (kde#359596)
  * http: rename m_iError to m_kioError
  * kio_http: read and discard body after a 404 with errorPage=false
  * kio_http: fix mimetype determination when URL ends with '/'
  * FavIconRequestJob: add accessor hostUrl() so that konqueror
    can find out what the job was for, in the slot
  * FavIconRequestJob: fix job hanging when aborting due to
    favicon too big
  * FavIconRequestJob: fix errorString(), it only had the URL
  * KIO::RenameDialog: restore preview support, add date and
    size labels (kde#356278)
  * KIO::RenameDialog: refactor duplicated code
  * Fix wrong path-to-QUrl conversions
  * Use kf5.kio in the category name to match other categories
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.20.0.php
* Fri Feb 12 2016 wbauer@tmo.at
- Install "Create New" templates to %%{_kf5_sharedir}/templates/ as
  a workaround until kde#356198 is fixed (boo#963680)
* Sat Feb  6 2016 hrvoje.senjan@gmail.com
- Update to 5.19.0 (boo#967668)
  * New class FavIconRequestJob in new lib KIOGui,
    for favicons retrieval
  * Fix KDirListerCache crash with two listers for an empty
    dir in the cache (kde#278431)
  * Make Windows implementation of KIO::stat for file:/ protocol
    error out if the file doesn't exist
  * Don't assume that files in read-only dir can't
    be deleted on Windows
  * Fix .pri file for KIOWidgets: it depends on KIOCore,
    not on itself
  * Repair kcookiejar autoload, the values got
    swapped in 6db255388532a4
  * Make kcookiejar accessible under the dbus
    service name org.kde.kcookiejar5
  * kssld: install DBus service file for org.kde.kssld5
  * Provide a DBus service file for org.kde.kpasswdserver
  * [kio_ftp] fix display of file/directory
    modification time/date (boo#960500, kde#354597)
  * [kio_help] fix garbage sent when serving static files
  * [kio_http] Try NTLMv2 authentication if the
    server denies NTLMv1
  * [kio_http] fix porting bugs which broke caching
  * [kio_http] Fix NTLMv2 stage 3 response creation
  * [kio_http] fix waiting until the cache cleaner
    listens to the socket
  * kio_http_cache_cleaner: don't exit on startup if
    cache dir doesn't exist yet
  * Change DBus name of kio_http_cache_cleaner so it
    doesn't exit if the kde4 one is running
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.19.0.php
- Drop upstreamed patches: fix-kcookiejar-autoload.patch and
  kio_ftp-fix-display-of-modification-time-date.patch
* Sun Jan 24 2016 tittiatcoke@gmail.com
- Added fix-kcookiejar-autoload.patch to fix the swapped values
  for the autoload.
* Thu Jan  7 2016 wbauer@tmo.at
- Added kio_ftp-fix-display-of-modification-time-date.patch: fixes
  display of file/directory modification time in kio_ftp
  (boo#960500, kde#354597)
* Sat Jan  2 2016 hrvoje.senjan@gmail.com
- Update to 5.18.0
  * Fix kiod for Qt 5.6's threaded dbus: messageFilter must wait
    until the module is loaded before returning
  * Change the error code when pasting/moving into a subdirectory
  * Fix emptyTrash blocked issue
  * Fix wrong button in KUrlNavigator for remote URLs
  * KUrlComboBox: fix returning an absolute path from urls()
  * kiod: disable session management
  * Add autocompletion for '.' input which offers all hidden
    files/folders* (kde#354981)
  * ktelnetservice: fix off by one in argc check
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.18.0.php
* Thu Dec 10 2015 hrvoje.senjan@gmail.com
- Update to 5.17.0
  * Cookie dialogue: make it work as intended
  * Fix filename suggestion changing to something random when
    changing save-as mimetype.
  * Register DBus name for kioexec (kde#353037)
  * Update KProtocolManager after configuration change.
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.17.0.php
- Drop upstreamed register-dbus-name-for-kioexec.patch
* Fri Nov 27 2015 wbauer@tmo.at
- Added register-dbus-name-for-kioexec.patch: prevent klauncher
  from freezing and displaying an error message when opening
  documents (boo#924764, kde#353037)
* Sun Nov  8 2015 hrvoje.senjan@gmail.com
- Update to 5.16.0 (boo#955067)
  * Save proxy url with correct scheme
  * Ship the "new file templates" in the kiofilewidgets library using
    a .qrc (kde#353642)
  * Properly handle middle click in navigatormenu
  * Make kio_http_cache_cleaner deployable in application
    installer/bundles
  * KOpenWithDialog: Fix creating desktop file with empty mimetype
  * Read protocol info from plugin metadata
  * Allow local kioslave deployment
  * Add a .protocol to JSON converted
  * Fix double-emit of result and missing warning when listing hits
    an inaccessible folder (kde#333436)
  * Preserve relative link targets when copying symlinks.
    (kde#352927)
  * Using suitable icons for default folders in the user home
    (kde#352498)
  * Add an interface which allow plugin to show custom overlay icons
  * Make KNotifications dep in KIO (kpac) optional
  * Make doctools + wallet optional
  * Avoid kio crashes if no dbus server is running
  * Add KUriFilterSearchProviderActions, to show a list of actions
    for searching some text using web shortcuts
  * Move the entries for the "Create New" menu from
    kde-baseapps/lib/konq to kio (kde#349654)
  * Move konqpopupmenuplugin.desktop from kde-baseapps to kio
    (kde#350769)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.16.0.php
- Drop 0001-Move-konqpopupmenuplugin.desktop-from-kde-baseapps-t.patch
  and 0001-Move-the-entries-for-the-Create-New-menu-from-kde-ba.patch,
  upstreamed
* Mon Oct  5 2015 hrvoje.senjan@gmail.com
- Update to 5.15.0
  * KFileWidget: parent argument should default to 0 like in
    all widgets.
  * Make sure the size of the byte array we just dumped into the
    struct is big enough before calculating the targetInfo,
    otherwise we're accessing memory that doesn't belong to us
  * Fix Qurl usage when calling QFileDialog::getExistingDirectory()
  * Refresh Solid's device list before querying in kio_trash
  * Allow trash: in addition to trash:/ as url for listDir
    (calls listRoot) (kde#353181)
  * KProtocolManager: fix deadlock when using EnvVarProxy.
    (kde#350890)
  * Don't try to find X11 on WIN32
  * KBuildSycocaProgressDialog: use Qt's builtin busy indicator.
    (kde#158672)
  * KBuildSycocaProgressDialog: run kbuildsycoca5 with QProcess.
  * KPropertiesDialog: fix for ~/.local being a symlink,
    compare canonical paths
  * Add support for network shares in kio_trash (kde#177023)
  * Connect to the signals of QDialogButtonBox, not QDialog
    (kde#352770)
  * Cookies KCM: update DBus names for kded5
  * Use JSON files directly instead of kcoreaddons_desktop_to_json()
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.15.0.php
* Sun Oct  4 2015 hrvoje.senjan@gmail.com
- Added 0001-Move-konqpopupmenuplugin.desktop-from-kde-baseapps-t.patch
  (kde#350769) and 0001-Move-the-entries-for-the-Create-New-menu-from-kde-ba.patch
  (kde#349654)
* Tue Sep  8 2015 hrvoje.senjan@gmail.com
- Update to 5.14.0
  * Use Q_OS_WIN instead of Q_OS_WINDOWS
  * Make KDE_FORK_SLAVES work under Windows
  * Disable installation of desktop file for ProxyScout kded module
  * Provide deterministic sort order for
    KDirSortFilterProxyModelPrivate::compare
  * Show custom folder icons again (kde#350612)
  * Move kpasswdserver from kded to kiod
  * Fix porting bugs in kpasswdserver
  * Remove legacy code for talking very very old versions
    of kpasswdserver.
  * KDirListerTest: use QTRY_COMPARE on both statements,
    to fix race showed by CI
  * KFilePlacesModel: implement old TODO about using trashrc
    instead of a full-blown KDirLister.
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.14.0.php
- Drop show-custom-folder-icons-sgain.patch, merged upstream
* Tue Aug 18 2015 hrvoje.senjan@gmail.com
- Added show-custom-folder-icons-sgain.patch (kde#350612)
* Tue Aug  4 2015 hrvoje.senjan@gmail.com
- Update to 5.13.0
  * The Qt version requirement has been bumped from 5.2 to 5.3
  * Debug output has been ported to categorized output, for less
    noise by default
  * Docbook documentation has been reviewed and updated
  * Kill unneeded QUrl wrappers
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.13.0.php
* Sun Jul  5 2015 hrvoje.senjan@gmail.com
- Update to 5.12.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.12.0.php
* Sun Jun  7 2015 hrvoje.senjan@gmail.com
- Update to 5.11.0
  * Do not try to complete users and assert when prepend is non-empty.
    (kde#346920)
  * Use KPluginLoader::factory() when loading KIO::DndPopupMenuPlugin
  * Fix deadlock when using network proxies (kde#346214)
  * Fixed KIO::suggestName to preserve file extensions
  * Kick off kbuildsycoca4 when updating sycoca5.
  * KFileWidget: Don't accept files in directory only mode
  * KIO::AccessManager: Make it possible to treat sequential
    QIODevice asynchronously
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.11.0.php
* Sun May  3 2015 hrvoje.senjan@gmail.com
- Update to 5.10.0
  * Added KPropertiesDialog::KPropertiesDialog(urls) and
    KPropertiesDialog::showDialog(urls).
  * Asynchronous QIODevice-based data fetch for KIO::storedPut and
    KIO::AccessManager::put.
  * Fix conditions with QFile::rename return value (kde#343329)
  * Fixed KIO::suggestName to suggest better names (kde#341773)
  * kioexec: Fixed path for writeable location for kurl
    (kde#343329)
  * Store bookmarks only in user-places.xbel (kde#345174)
  * Duplicate RecentDocuments entry if two different files
    have the same name
  * Better error message if a single file is too large for
    the trash (kde#332692)
  * Fix KDirLister crash upon redirection when the slot calls openURL
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.10.0.php
* Sat Apr  4 2015 hrvoje.senjan@gmail.com
- Update to 5.9.0
  * Enable KPropertiesDialog to show free space information of
    remote file systems as well (e.g. smb)
  * Fix KUrlNavigator with high DPI pixmaps
  * Make KFileItemDelegate handle non default devicePixelRatio
    in animations
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.9.0.php
- Split the core modules/daemons/libraries into core subpackage;
  based on upstream KIOCORE_ONLY build option, which only concerns
  the buildsystem, not the code (i.e. no ifdefs)
- Add kio_help-fallback-to-kde4-docs.patch: allow kio_help to see
  into kde4 documentation
* Mon Mar 16 2015 hrvoje.senjan@gmail.com
- Add missing requires to devel subpackage: kcoreaddons-devel,
  kconfig-devel and kitemviews-devel
- Drop unneeded kcrash-devel BuildRequires
* Sat Mar  7 2015 hrvoje.senjan@gmail.com
- Update to 5.8.0
  * Deprecate UDSEntry::listFields and add the UDSEntry::fields
    method which returns a QVector without costly conversion.
  * Sync bookmarkmanager only if change was by this process
    (kde#343735)
  * Fix startup of kssld5 dbus service
  * Implement quota-used-bytes and quota-available-bytes from
    RFC 4331 to enable free space information in http ioslave.
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.8.0.php
- Drop 0001-sync-bookmarkmanager-only-if-change-was-by-process.patch,
  merged upstream
* Sun Feb  8 2015 hrvoje.senjan@gmail.com
- Update to 5.7.0
  * Fixed crash in jobs when linking to KIOWidgets but only
    using a QCoreApplication
  * Fixed editing web shortcuts
  * Added option KIOCORE_ONLY, to compile only KIOCore and its
    helper programs, but not KIOWidgets or KIOFileWidgets, thus
    reducing greatly the necessary dependencies
  * Added class KFileCopyToMenu, which adds Copy To / Move To"
    to popupmenus
  * SSL-enabled protocols: added support for TLSv1.1 and TLSv1.2
    protocols, remove SSLv3
  * Fixed negotiatedSslVersion and negotiatedSslVersionName to
    return the actual negotiated protocol
  * Apply the entered URL to the view when clicking the button
    that switches the URL navigator back to breadcrumb mode
  * Fixed two progress bars/dialogs appearing for copy/move jobs
  * KIO now uses its own daemon, kiod, for out-of-process services
    previously running in kded, in order to reduce dependencies;
    currently only replaces kssld
  * Fixed "Could not write to <path>" error when kioexec is triggered
  * Fixed "QFileInfo::absolutePath: Constructed with empty filename"
    warnings when using KFilePlacesModel
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.7.0.php
- Added 0001-sync-bookmarkmanager-only-if-change-was-by-process.patch,
  kde#343735
* Sat Jan  3 2015 hrvoje.senjan@gmail.com
- Update to 5.6.0
  * Add support for .hidden files, for users to hide some files
    from views. (kde#246260)
  * New method KRun::runService, like KRun::run but returns the
    PID of the newly started process.
  * kioexec: fixed many porting bugs, to make it work again
  * KRun::run: fixed porting bug, to make it work again in the
    case where KProcess is used directly
  * KRun: make klauncher runtime dependency optional
  * Fix compilation on MSVC
  * Performance: decrease memory consumption of UDSEntry
  * Actions in popupmenus: in case of multiple mimetypes selected,
    services that support all mimetypes are now added to the menu.
  * New job: KIO::DropJob *KIO::drop(QDropEvent* ev, QUrl destUrl).
    Replaces KonqOperations::doDrop.
  * Restart directory watcher after a failed delete operation
  * Fix false warning about X-KDE-Protocols unused in desktop
    files without that field.
  * Merge various settings modules (KCMs) related to kio,
    into the kio framework.
  * When copying/moving out the trash, make the files writable.
  * KIO::file_move now does the chmod on the destination file
    before emitting result.
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.6.0.php
* Sat Dec  6 2014 hrvoje.senjan@gmail.com
- Update to 5.5.0
  * Fix Size columns being empty in the KFileWidget detailed views
  * Do not drop ASN passed to KRun when executing desktop files
  * Fix passing of DESKTOP_STARTUP_ID to child process in kioexec
  * Fix compilation with Qt 5.2, which also fixes a race condition
  * KFileItem: cleanup overlay icon usage
  * Implement back/forward side mouse buttons
    to navigate in the history
  * Allow user to cancel out of the certificate
    accept duration dialog box.
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.5.0.php
- Added pkgconfig(Qt5X11Extras) BuildRequires
* Sun Nov  2 2014 hrvoje.senjan@gmail.com
- Update to 5.4.0
  * New job KIO::mkpath()
  * New job KIO::PasteJob, handles pasting+dropping URLs and data;
    KIO::paste replaces KIO::pasteClipboard
  * New function KIO::pasteActionText, to handle the paste action
  * When clicking on a script or desktop file in a file manager,
    let the user choose between executing and vieweing as text
  * KUrlRequester: fixing handling of start directory
  * Offer also overwrite option when copying multiple files and
    there is a conflict (regression compared to kdelibs4)
  * KDirLister: do not kill+restart running update jobs.
  * KDirLister: don't emit refreshItems for items that
    haven't changed.
  * Prevent incorrect disk full error messages on mounts where we
    cannot determine the amount of free space.
  * Fix running the file type editor
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.4.0.php
- Added kinit Recommends
* Sat Oct  4 2014 hrvoje.senjan@gmail.com
- Update to 5.3.0
  * Now includes kio_trash
  * Add new KIO job, KIO::fileSystemFreeSpace, that allows you to
    get a filesystem's total and available space.
  * kshorturifilter: Remove redundant forward slashes from
    the beginning of an URI
  * Add searchprovider definitions for the qwant search engine
  * File dialog: fix relative paths being turned into HTTP URLs
  * Fix thumbnails for mimetype groups.
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.3.0.php
- Drop patches merged upstream:
  0001-Add-new-KIO-job-KIO-fileSystemFreeSpace-that-allows-.patch,
  0001-Fix-thumbnails-for-mimetype-groups.patch and
  0002-Fix-relative-paths-being-turned-into-http-urls-by-fr.patch
* Fri Sep 26 2014 hrvoje.senjan@gmail.com
- Add 0001-Add-new-KIO-job-KIO-fileSystemFreeSpace-that-allows-.patch
  from upstream:  allows you to get a filesystem's total and
  available space.
* Tue Sep  9 2014 hrvoje.senjan@gmail.com
- Update to 5.2.0
  * KIO/KService: now follows the mime-apps spec, for better
    interoperability with gio when it comes to the user's
    preferred and default apps.
  * KIO: new classes EmptyTrashJob and RestoreJob
  * KIO: new functions isClipboardDataCut and setClipboardDataCut.
  * For more details please see:
    http://kde.org/announcements/kde-frameworks-5.2.php
- Added 0001-Fix-thumbnails-for-mimetype-groups.patch, fixes thumbnail
  generation for mimetypes with wildcard usage
- 0002-Fix-relative-paths-being-turned-into-http-urls-by-fr.patch,
  fixes filedialog appening 'http://' on directory change
* Sat Aug  2 2014 hrvoje.senjan@gmail.com
- Update to 5.1.0
  * For more details please see:
    http://www.kde.org/announcements/kde-frameworks-5.1.php
- Drop 0004-When-executing-commands-set-the-working-directory-to.patch,
  0005-Fix-template-discovery-in-KNewFileMenu.patch,
  0007-fix-kurlrequester-dialog-accept-handling.patch and
  0008-warn-about-asserting-when-people-can-t-write-proper-.patch,
  merged upstream
* Fri Jul 11 2014 hrvoje.senjan@gmail.com
- Define kf5_version within package
- Added patches from upstream:
  0004-When-executing-commands-set-the-working-directory-to.patch,
  0005-Fix-template-discovery-in-KNewFileMenu.patch,
  0007-fix-kurlrequester-dialog-accept-handling.patch and
  0008-warn-about-asserting-when-people-can-t-write-proper-.patch
* Tue Jul  1 2014 hrvoje.senjan@gmail.com
- Update to 5.0.0
  * Final release of KDE Frameworks 5
  * API improvements and cleanups
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/kde-frameworks-5.0.php
* Sun Jun  1 2014 hrvoje.senjan@gmail.com
- Update to 4.100.0
  * API improvements and cleanups
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/announce-frameworks5-beta3.php
- Recommend kio-extras5
- Add baselibs.conf
* Sun May  4 2014 hrvoje.senjan@gmail.com
- Update to 4.99.0
  * API improvements and cleanups
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/announce-frameworks5-beta2.php
* Sat Mar 29 2014 hrvoje.senjan@gmail.com
- Update to 4.98.0
  * API improvements and cleanups
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/announce-frameworks5-beta1.php
- Added kwallet-devel BuildRequires
* Tue Mar  4 2014 hrvoje.senjan@gmail.com
- Update to 4.97.0:
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/announce-frameworks5-alpha2.php
* Sat Feb  8 2014 hrvoje.senjan@gmail.com
- Init kio package
